'use client'
import React, { useEffect, useState } from "react";
import { cn, isLocationMatch } from "@/lib/utils";
import menusConfig from "../../../menus";
import menusConfigMD from "../../../menusMd";
import menusConfigD from "../../../menusD";
import menusConfigRT from "../../../menusRT";
import menusConfigMA from "../../../menusMA";
import menusConfigAPI from '../../../menusAPI';
import menusConfigOP from '../../../menueOperations';
import menusConfigFin from '../../../menusFin';
import SingleIconMenu from "./single-icon-menu";
import { useRouter, usePathname } from "next/navigation";
import { useSidebar } from "@/store";
import MenuItem from "./menu-item";
import NestedMenus from "./nested-menus";
import FooterMenu from "./footer-menu";
import { SiteLogo } from "@/components/svg";
import { ScrollArea } from "@/components/ui/scroll-area";
import LogoutFooter from "./logout-footer";
import { useMediaQuery } from "@/hooks/use-media-query";
import MenuOverlayPortal from "./MenuOverlayPortal";
import { ChevronLeft } from "lucide-react";
import { Button } from "@/components/ui/button";
import { getApiData, getWithToken } from "@/Helper/common";
import { useTranslations } from "next-intl";
import logo from '../../../../public/lolo.webp'
import Link from "next/link";
import Image from "next/image";
import { ClipLoader } from "react-spinners";


const ModuleSidebar = ({ userKycData, dataTheme }) => {
  const t = useTranslations("Menu");
  const [kycDetailsData, setKycDetailsData] = useState([]);
  const [userDetailsData, setUserDetailsData] = useState([]);
  const [menus, setMenuData] = useState([]);
  const { sidebarNav } = menusConfig();
  const { sidebarNavMD } = menusConfigMD();
  const { sidebarNavAPI } = menusConfigAPI();
  const { sidebarD } = menusConfigD();
  const { sidebarMA } = menusConfigMA();
  const { sidebarRT } = menusConfigRT();
  const { sidebarOP } = menusConfigOP();
  const { sidebarFin } = menusConfigFin();
  const { subMenu, setSubmenu, collapsed, setCollapsed, sidebarBg, showText, setShowText } = useSidebar();
  const [activeIndex, setActiveIndex] = useState(null);
  const [currentSubMenu, setCurrentSubMenu] = useState([]);
  const [nestedIndex, setNestedIndex] = useState(null);
  const [multiNestedIndex, setMultiNestedIndex] = useState(null);
  const [menuOverlay, setMenuOverlay] = useState(false);
  const [menuApiLoading, setMenuApiLoading] = useState(true);
  const isDesktop = useMediaQuery("(min-width: 1280px)");
  const locationName = usePathname();

  // dynamic logo and name 
  const [data, setData] = useState(dataTheme?.result);

  var apiCall = true;

  const fetchData = async () => {
    try {

      if (apiCall) {

        apiCall = false;

        // const apiResData = await getApiData("theme-setting/single");
        // if (apiResData.error === false) {
        //   setData(apiResData.result);
        // } else {
        //   setData([])
        // }
      }
    } catch (error) {
      console.error("Error fetching:", error);
    } finally {

    }
  };

  useEffect(() => {
    fetchData();
  }, []);

  useEffect(() => {

    fetchKycData();
  }, [t]);

  var apiCall1 = true;

  const fetchKycData = async () => {
    try {
      setCollapsed(true)
      // setShowText(true)
      if (apiCall1) {

        apiCall1 = false;

        const apiResData = userKycData;
        // alert(apiResData)
        if (apiResData.error === false) {
          setKycDetailsData(userKycData.data);
          setUserDetailsData(userKycData.userData);

          const designationId = apiResData.userData.designation_id;
          // console.log(designationId, "desig");

          let selectedMenu = [];
          if (designationId === 1) {
            selectedMenu = sidebarNav?.modern || [];
          } else if (designationId === 2) {
            selectedMenu = sidebarMA?.modern || [];
          } else if (designationId === 3) {
            selectedMenu = sidebarNavMD?.modern || [];
          } else if (designationId === 4) {
            selectedMenu = sidebarD?.modern || [];
          } else if (designationId === 5) {
            selectedMenu = sidebarRT?.modern || [];

          } else if (designationId === 6) {
            selectedMenu = sidebarNavAPI?.modern || [];
          } else if (designationId === 7) {
            // console.log(sidebarOP);
            selectedMenu = sidebarOP?.modern || [];
          } else if (designationId === 8) {
            selectedMenu = sidebarFin?.modern || [];
          } else {
            selectedMenu = sidebarNav?.modern || [];
          }

          console.log(selectedMenu);

          setMenuData(selectedMenu.map(menu => ({
            ...menu,
            title: menu.title,
            child: menu.child?.map(subMenu => ({
              ...subMenu,
              title: subMenu.title,
              nested: subMenu.nested?.map(nestedMenu => ({
                ...nestedMenu,
                title: nestedMenu.title
              }))
            }))
          })));

          setMenuApiLoading(false);
        }
      }

    } catch (error) {
      console.error("Error fetching :", error);
    }
  };

  const toggleSubMenu = (index) => {
    toggleNested();
    setActiveIndex(index);
    if (menus[index].child) {
      setCurrentSubMenu(menus[index].child);
      setSubmenu(false);
      setCollapsed(false);
      if (!isDesktop) {
        setMenuOverlay(true);
        setCollapsed(!collapsed);
      }
    } else {
      if (!isDesktop) {
        setCollapsed(false);
      }

      setSubmenu(true);
      setCollapsed(true);
      if (!isDesktop) {
        if (isLocationMatch(menus[index].href, locationName)) {
          setSubmenu(false);
        }
      }
    }
  };


  const toggleNested = (subIndex) => {
    setNestedIndex(nestedIndex === subIndex ? null : subIndex);

  };

  const toggleMultiNested = (index) => {
    setMultiNestedIndex(multiNestedIndex === index ? null : index);

  };

  const setActiveMenu = (menuIndex, childMenu) => {
    setActiveIndex(menuIndex);
    setCurrentSubMenu(childMenu);
    setSubmenu(false);
    if (!isDesktop) {
      setCollapsed(false);
    } else {
      setCollapsed(true);
    }
  };

  const setActiveNestedMenu = (menuIndex, nestedMenuIndex, childMenu) => {
    setActiveIndex(menuIndex);
    setNestedIndex(nestedMenuIndex);
    setCurrentSubMenu(childMenu);
    setSubmenu(false);
    setCollapsed(false);

  };

  const getMenuTitle = () => {
    return activeIndex !== null ? menus[activeIndex].title : "";
  };

  useEffect(() => {
    let isMenuMatched = false;
    menus.forEach((item, i) => {
      if (isLocationMatch(item.href, locationName)) {
        isMenuMatched = true;
        setSubmenu(true);
        setCollapsed(true);
        setMenuOverlay(false);
      }

      // menu set
      if (!isDesktop) {
        setCollapsed(false);
      } else {
        setCollapsed(true);
      }


      item?.child?.forEach((childItem, j) => {
        if (isLocationMatch(childItem.href, locationName)) {
          setActiveMenu(i, item.child);
          setMenuOverlay(false);
          isMenuMatched = true;
        }

        if (childItem.nested) {
          childItem.nested.forEach((nestedItem) => {
            if (isLocationMatch(nestedItem.href, locationName)) {
              setActiveNestedMenu(i, j, item.child);
              setMenuOverlay(false);
              isMenuMatched = true;
            }
            if (nestedItem.child) {
              nestedItem.child.forEach((multiItem, k) => {
                if (isLocationMatch(multiItem.href, locationName)) {
                  setActiveNestedMenu(i, j, item.child);
                  setMenuOverlay(false);
                  isMenuMatched = true;
                }
              });
            }
          });
        }
      });
    });
    if (!isMenuMatched) {
      setSubmenu(false);
    }
    if (!isDesktop) {
      setSubmenu(true);
    }
  }, [locationName, isDesktop, menus]);


  const router = useRouter()

  const handleMenuClick = () => {

    if (!isDesktop) {
      setCollapsed(!collapsed);
      setMenuOverlay(false);
    }
  };

  return (

    menuApiLoading == false ?

      <>

        <div className="main-sidebar  pointer-events-none fixed start-0 top-0 z-[60] flex h-full xl:z-10 print:hidden">
          <div
            className={cn(
              "border-default-200 dark:border-default-300 pointer-events-auto relative z-20 flex h-full flex-col border-r border-dashed bg-card transition-all duration-300",
              !showText && "w-[220px]",
              {
                "-translate-x-full xl:translate-x-0 w-[220px]": !collapsed && subMenu && isDesktop && !showText,
                "translate-x-0 w-[80px]": collapsed && isDesktop && showText,
                "-translate-x-full xl:translate-x-0 w-[72px]": !collapsed && subMenu && !isDesktop,
                "translate-x-0 w-[180px]": collapsed && !isDesktop,
              }
            )}
            >
            {
              showText && <div className="p-2 self-center transition-none">
                <Link href="/admin/dashboard" onClick={() => handleMenuClick()} >
                  <img src={dataTheme?.result?.logo} height={40} width={40} />

                </Link>
              </div>
            }
            {
              !showText && <div className="p-2 self-center transition-none">
                <Link href="/admin/dashboard" onClick={() => handleMenuClick()} >
                  <img src={dataTheme?.result?.logo} height={80} width={150} />
                </Link>
              </div>
            }
            {/* end logo */}
            <ScrollArea className=" pt-6 grow">
              {menus.map((item, i) => (
                <div
                  key={i}
                  onClick={() => toggleSubMenu(i)}
                  className=" mb-3 last:mb-0"
                  locationName={locationName}
                >
                  <SingleIconMenu
                    index={i}
                    activeIndex={activeIndex}
                    item={item}
                  />
                </div>

              ))}
            </ScrollArea>
            <FooterMenu />
          </div>
          {/* end small menu */}

          <div style={{ marginRight: "100px" }}
            className={cn(
              "border-default-200 pointer-events-auto relative z-10 flex flex-col h-full w-[220px] border-r  bg-card   transition-all duration-300",
              {
                "rtl:translate-x-[calc(100%_+_72px)] translate-x-[calc(-100%_-_72px)]":
                  collapsed || subMenu,
              }
            )}
          >
            {sidebarBg !== "none" && (
              <div
                className=" absolute left-0 top-0   z-[-1] w-full h-full bg-cover bg-center opacity-[0.07]"
                style={{ backgroundImage: `url(${sidebarBg})` }}
              ></div>
            )}
            <h2 className="text-lg  bg-transparent   z-50   font-semibold  flex gap-4 items-center   text-default-700 sticky top-0 py-4  px-4   ">
              <span className=" block ">{getMenuTitle()}</span>
              {!isDesktop && (
                <Button
                  size="icon"
                  variant="ghost"
                  onClick={() => {
                    setCollapsed(true);
                    setSubmenu(true);
                    setMenuOverlay(false);
                  }}
                  className="rounded-full h-8 w-8"
                >
                  <ChevronLeft className="w-5 h-5  " />
                </Button>
              )}
              {isDesktop && (
                <Button
                  size="icon"
                  variant="ghost"
                  onClick={() => {
                    setCollapsed(true)
                  }}
                  className="rounded-full h-8 w-8"
                >
                  <ChevronLeft className="w-5 h-5  " />
                </Button>
              )}
            </h2>
            <ScrollArea className="h-[calc(100%-40px)]  grow ">
              <div className="px-2 ">
                <ul>
                  {currentSubMenu?.map((childItem, j) => (
                    <li key={j} className="mb-1.5 last:mb-0" onClick={() => setCollapsed(true)}>
                      <MenuItem
                        childItem={childItem}
                        toggleNested={toggleNested}
                        index={j}
                        nestedIndex={nestedIndex}
                        locationName={locationName}

                      />
                      <NestedMenus
                        index={j}
                        nestedIndex={nestedIndex}
                        nestedMenus={childItem.nested}
                        locationName={locationName}
                        toggleMulti={toggleMultiNested}
                        multiIndex={multiNestedIndex}
                      />
                    </li>
                  ))}
                </ul>
              </div>
            </ScrollArea>
            <LogoutFooter />
          </div>
          {/* end main panel */}
        </div>
        {!isDesktop && (
          <MenuOverlayPortal
            isOpen={menuOverlay || collapsed}
            onClose={() => {
              setMenuOverlay(false);
              setSubmenu(true);
              setCollapsed(false);
            }}
          />
        )}
      </>

      :

      <>
        <div className="main-sidebar  pointer-events-none fixed start-0 top-0 z-[60] flex h-full xl:z-10 print:hidden">
          <div
            className={cn(
              "border-default-200  dark:border-default-300 pointer-events-auto relative z-20 flex h-full  flex-col border-r border-dashed   bg-card transition-all duration-300 ",
              {
                "-translate-x-full xl:translate-x-0 w-[200px]": !collapsed && subMenu && isDesktop,
                "translate-x-0 w-[200px]": collapsed && isDesktop,
                "-translate-x-full xl:translate-x-0 w-[72px]": !collapsed && subMenu && !isDesktop,
                "translate-x-0 w-[180px]": collapsed && !isDesktop,
              }
            )}
          >
            <div className=" pt-4 ">

            </div>
            {/* end logo */}
            <ScrollArea className=" pt-6 grow" style={{ textAlign: 'center' }}>

              <div

                onClick={() => toggleSubMenu(i)}
                className=" mb-3 last:mb-0"
                locationName={locationName}
              >
                <ClipLoader />
              </div>


            </ScrollArea>
            <FooterMenu />
          </div>

        </div>
      </>


  );
};

export default ModuleSidebar;


